import { By, WebElement } from 'selenium-webdriver';
import { ElementCondition } from './conditions';
import { Configuration } from './configuration';
import { Element } from './element';
import { Assertable, Entity, Matchable } from './entity';
import { Locator } from './locators/locator';
export declare class Collection extends Entity implements Assertable, Matchable {
    private readonly locator;
    constructor(locator: Locator<Promise<WebElement[]>>, configuration: Configuration);
    with(customConfig: Partial<Configuration>): Collection;
    getAsCashedArray(): Promise<Element[]>;
    elementAt(index: number): Element;
    get first(): Element;
    get second(): Element;
    /**
     * Represents a new collection sliced from 'start' element index to 'end' element index exclusive.
     * @param start The inclusive "start" index of collection to be sliced.
     * @param end The exclusive "end" index of collection to be sliced
     * @param step The step of slicing. Default is 1.
     */
    sliced(start: number, end: number, step?: number): Collection;
    get even(): Collection;
    get odd(): Collection;
    filteredBy(...conditions: ElementCondition[]): Collection;
    by(...conditions: ElementCondition[]): Collection;
    elementBy(...conditions: ElementCondition[]): Element;
    collected(searchFunction: (element: Element) => Element | Collection): Collection;
    all(located: (string | By | Locator<Promise<WebElement[]>> | {
        script: string | ((element: HTMLElement) => HTMLCollectionOf<HTMLElement>);
        args?: any[];
    })): Collection;
    allFirst(located: (string | By | Locator<Promise<WebElement>> | {
        script: string | ((element: HTMLElement) => HTMLElement | ShadowRoot);
        args?: any[];
    })): Collection;
    getWebElements(): Promise<WebElement[]>;
    toString(): string;
}
